BASE_URL = "https://api.adup-tech.com"

FIELDS = {
    "ACCOUNT_PERFORMANCE_REPORT": [
        "AccountDescriptiveName",
        "AccountId",
        "AllConversions",
        "AverageCost",
        "AverageCpc",
        "AverageCpm",
        "AveragePosition",
        "Clicks",
        "ConversionRate",
        "Conversions",
        "Cost",
        "CostPerAllConversion",
        "CostPerConversion",
        "Ctr",
        "Date",
        "Impressions",
        "InteractionRate",
        "Interactions",
        "InvalidClickRate",
        "InvalidClicks",
        "ViewThroughConversions",
    ],
    "AD_PERFORMANCE_REPORT": [
        "AccountDescriptiveName",
        "AccountId",
        "AdgroupId",
        "AdgroupName",
        "AdgroupStatus",
        "AdName",
        "AllConversions",
        "AverageCost",
        "AverageCpc",
        "AverageCpm",
        "AveragePosition",
        "CampaignId",
        "CampaignName",
        "CampaignStatus",
        "Clicks",
        "ConversionRate",
        "Conversions",
        "Cost",
        "CostPerAllConversion",
        "CostPerConversion",
        "CreativeFinalMobileUrl",
        "CreativeFinalUrl",
        "CreativeFinalUrlSuffix",
        "Ctr",
        "Date",
        "Description",
        "DisplayUrl",
        "Headline",
        "Impressions",
        "InteractionRate",
        "Interactions",
        "Path1",
        "Path2",
        "ViewThroughConversions",
    ],
    "CAMPAIGN_PERFORMANCE_REPORT": [
        "AccountDescriptiveName",
        "AccountId",
        "AllConversionRate",
        "AllConversions",
        "AverageCost",
        "AverageCpc",
        "AverageCpm",
        "AveragePosition",
        "CampaignDesktopBidModifier",
        "CampaignId",
        "CampaignMobileBidModifier",
        "CampaignName",
        "CampaignStatus",
        "CampaignTabletBidModifier",
        "Clicks",
        "ConversionRate",
        "Conversions",
        "Cost",
        "CostPerAllConversion",
        "CostPerConversion",
        "Ctr",
        "Date",
        "Device",
        "EndDate",
        "Impressions",
        "InteractionRate",
        "Interactions",
        "InvalidClickRate",
        "InvalidClicks",
        "Period",
        "StartDate",
        "TrackingUrlTemplate",
        "ViewThroughConversions",
    ],
    "DIRECT_PLACEMENT_PERFORMANCE_REPORT": [
        "AccountDescriptiveName",
        "AccountId",
        "AdgroupName",
        "AdgroupStatus",
        "AllConversions",
        "AverageCost",
        "AverageCpc",
        "AverageCpm",
        "AveragePosition",
        "CampaignId",
        "CampaignName",
        "CampaignStatus",
        "Clicks",
        "ConversionRate",
        "Conversions",
        "Cost",
        "CostPerAllConversion",
        "CostPerConversion",
        "Ctr",
        "Date",
        "DisplayName",
        "Id",
        "Impressions",
        "InteractionRate",
        "Interactions",
        "ViewThroughConversions",
    ],
    "PLACEMENTLAYOUT_PERFORMANCE_REPORT": [
        "AverageContainerCpm",
        "AverageCpc",
        "AverageCpm",
        "Clicks",
        "ContainerCtr",
        "ContainerImpressions",
        "ContainerInvalidClickRate",
        "Ctr",
        "Date",
        "Impressions",
        "InvalidClickRate",
        "InvalidClicks",
        "PlacementId",
        "PlacementLayoutId",
        "PlacementLayoutName",
        "PlacementLayoutStatus",
        "PlacementName",
        "Revenue",
        "SiteId",
        "SiteName",
    ],
}
