# ------------------------------------------------------------------
# PRODUCTS
# ------------------------------------------------------------------

PRODUCTS_CAMPAIGN_METRICS = [
    "adGroupId",
    "adGroupName",
    "adStatus",
    "attributedSalesSameSku14d",
    "attributedSalesSameSku1d",
    "attributedSalesSameSku30d",
    "attributedSalesSameSku7d",
    "campaignApplicableBudgetRuleId",
    "campaignApplicableBudgetRuleName",
    "campaignBiddingStrategy",
    "campaignBudgetAmount",
    "campaignBudgetCurrencyCode",
    "campaignBudgetType",
    "campaignId",
    "campaignName",
    "campaignRuleBasedBudgetAmount",
    "campaignStatus",
    "clicks",
    "clickThroughRate",
    "cost",
    "costPerClick",
    "date",
    "impressions",
    "kindleEditionNormalizedPagesRead14d",
    "kindleEditionNormalizedPagesRoyalties14d",
    "purchases14d",
    "purchases1d",
    "purchases30d",
    "purchases7d",
    "purchasesSameSku14d",
    "purchasesSameSku1d",
    "purchasesSameSku30d",
    "purchasesSameSku7d",
    "sales14d",
    "sales1d",
    "sales30d",
    "sales7d",
    "spend",
    "unitsSoldClicks14d",
    "unitsSoldClicks1d",
    "unitsSoldClicks30d",
    "unitsSoldClicks7d",
    "unitsSoldSameSku14d",
    "unitsSoldSameSku1d",
    "unitsSoldSameSku30d",
    "unitsSoldSameSku7d",
]

PRODUCTS_TARGETING_METRICS = [
    "acosClicks14d",
    "acosClicks7d",
    "adGroupId",
    "adGroupName",
    "attributedSalesSameSku14d",
    "attributedSalesSameSku1d",
    "attributedSalesSameSku30d",
    "attributedSalesSameSku7d",
    "campaignBudgetAmount",
    "campaignBudgetCurrencyCode",
    "campaignBudgetType",
    "campaignId",
    "campaignName",
    "campaignStatus",
    "clicks",
    "clickThroughRate",
    "cost",
    "costPerClick",
    "date",
    "impressions",
    "keyword",
    "keywordBid",
    "keywordId",
    "keywordType",
    "kindleEditionNormalizedPagesRead14d",
    "kindleEditionNormalizedPagesRoyalties14d",
    "matchType",
    "portfolioId",
    "purchases14d",
    "purchases1d",
    "purchases30d",
    "purchases7d",
    "purchasesSameSku14d",
    "purchasesSameSku1d",
    "purchasesSameSku30d",
    "purchasesSameSku7d",
    "roasClicks14d",
    "roasClicks7d",
    "sales14d",
    "sales1d",
    "sales30d",
    "sales7d",
    "salesOtherSku7d",
    "targeting",
    "topOfSearchImpressionShare",
    "unitsSoldClicks14d",
    "unitsSoldClicks1d",
    "unitsSoldClicks30d",
    "unitsSoldClicks7d",
    "unitsSoldOtherSku7d",
    "unitsSoldSameSku14d",
    "unitsSoldSameSku1d",
    "unitsSoldSameSku30d",
    "unitsSoldSameSku7d",
]

PRODUCTS_SEARCH_TERM_METRICS = [
    "acosClicks14d",
    "acosClicks7d",
    "adGroupId",
    "adGroupName",
    "adKeywordStatus",
    "attributedSalesSameSku14d",
    "attributedSalesSameSku1d",
    "attributedSalesSameSku30d",
    "attributedSalesSameSku7d",
    "campaignBudgetAmount",
    "campaignBudgetCurrencyCode",
    "campaignBudgetType",
    "campaignId",
    "campaignName",
    "campaignStatus",
    "clicks",
    "clickThroughRate",
    "cost",
    "costPerClick",
    "date",
    "impressions",
    "keyword",
    "keywordBid",
    "keywordId",
    "keywordType",
    "kindleEditionNormalizedPagesRead14d",
    "kindleEditionNormalizedPagesRoyalties14d",
    "matchType",
    "portfolioId",
    "purchases14d",
    "purchases1d",
    "purchases30d",
    "purchases7d",
    "purchasesSameSku14d",
    "purchasesSameSku1d",
    "purchasesSameSku30d",
    "purchasesSameSku7d",
    "roasClicks14d",
    "roasClicks7d",
    "sales14d",
    "sales1d",
    "sales30d",
    "sales7d",
    "salesOtherSku7d",
    "searchTerm",
    "targeting",
    "unitsSoldClicks14d",
    "unitsSoldClicks1d",
    "unitsSoldClicks30d",
    "unitsSoldClicks7d",
    "unitsSoldOtherSku7d",
    "unitsSoldSameSku14d",
    "unitsSoldSameSku1d",
    "unitsSoldSameSku30d",
    "unitsSoldSameSku7d",
]

PRODUCTS_ADVERTISED_PRODUCT_METRICS = [
    "acosClicks14d",
    "acosClicks7d",
    "adGroupId",
    "adGroupName",
    "adId",
    "advertisedAsin",
    "advertisedSku",
    "attributedSalesSameSku14d",
    "attributedSalesSameSku1d",
    "attributedSalesSameSku30d",
    "attributedSalesSameSku7d",
    "campaignBudgetAmount",
    "campaignBudgetCurrencyCode",
    "campaignBudgetType",
    "campaignId",
    "campaignName",
    "campaignStatus",
    "clicks",
    "clickThroughRate",
    "cost",
    "costPerClick",
    "date",
    "impressions",
    "kindleEditionNormalizedPagesRead14d",
    "kindleEditionNormalizedPagesRoyalties14d",
    "portfolioId",
    "purchases14d",
    "purchases1d",
    "purchases30d",
    "purchases7d",
    "purchasesSameSku14d",
    "purchasesSameSku1d",
    "purchasesSameSku30d",
    "purchasesSameSku7d",
    "roasClicks14d",
    "roasClicks7d",
    "sales14d",
    "sales1d",
    "sales30d",
    "sales7d",
    "salesOtherSku7d",
    "spend",
    "unitsSoldClicks14d",
    "unitsSoldClicks1d",
    "unitsSoldClicks30d",
    "unitsSoldClicks7d",
    "unitsSoldOtherSku7d",
    "unitsSoldSameSku14d",
    "unitsSoldSameSku1d",
    "unitsSoldSameSku30d",
    "unitsSoldSameSku7d",
]

PRODUCTS_PURCHASED_PRODUCT_METRICS = [
    "adGroupId",
    "adGroupName",
    "advertisedAsin",
    "advertisedSku",
    "campaignBudgetCurrencyCode",
    "campaignId",
    "campaignName",
    "date",
    "keyword",
    "keywordId",
    "keywordType",
    "kindleEditionNormalizedPagesRead14d",
    "kindleEditionNormalizedPagesRoyalties14d",
    "matchType",
    "portfolioId",
    "purchasedAsin",
    "purchases14d",
    "purchases1d",
    "purchases30d",
    "purchases7d",
    "purchasesOtherSku14d",
    "purchasesOtherSku1d",
    "purchasesOtherSku30d",
    "purchasesOtherSku7d",
    "sales14d",
    "sales1d",
    "sales30d",
    "sales7d",
    "salesOtherSku14d",
    "salesOtherSku1d",
    "salesOtherSku30d",
    "salesOtherSku7d",
    "unitsSoldClicks14d",
    "unitsSoldClicks1d",
    "unitsSoldClicks30d",
    "unitsSoldClicks7d",
    "unitsSoldOtherSku14d",
    "unitsSoldOtherSku1d",
    "unitsSoldOtherSku30d",
    "unitsSoldOtherSku7d",
]

PRODUCTS_GROSS_AND_INVALID_TRAFFIC_METRICS = [
    "campaignName",
    "campaignStatus",
    "clicks",
    "date",
    "grossClickThroughs",
    "grossImpressions",
    "impressions",
    "invalidClickThroughRate",
    "invalidClickThroughs",
    "invalidImpressionRate",
    "invalidImpressions",
]

# ------------------------------------------------------------------
# BRANDS
# ------------------------------------------------------------------

BRANDS_CAMPAIGN_METRICS = [
    "addToCart",
    "addToCartClicks",
    "addToCartRate",
    "brandedSearches",
    "brandedSearchesClicks",
    "campaignBudgetAmount",
    "campaignBudgetCurrencyCode",
    "campaignBudgetType",
    "campaignId",
    "campaignName",
    "campaignRuleBasedBudgetAmount",
    "campaignStatus",
    "clicks",
    "cost",
    "costType",
    "date",
    "detailPageViews",
    "detailPageViewsClicks",
    "eCPAddToCart",
    "impressions",
    "kindleEditionNormalizedPagesRead14d",
    "kindleEditionNormalizedPagesRoyalties14d",
    "newToBrandDetailPageViewRate",
    "newToBrandDetailPageViews",
    "newToBrandDetailPageViewsClicks",
    "newToBrandECPDetailPageView",
    "newToBrandPurchases",
    "newToBrandPurchasesClicks",
    "newToBrandPurchasesPercentage",
    "newToBrandPurchasesRate",
    "newToBrandSales",
    "newToBrandSalesClicks",
    "newToBrandSalesPercentage",
    "newToBrandUnitsSold",
    "newToBrandUnitsSoldClicks",
    "newToBrandUnitsSoldPercentage",
    "purchases",
    "purchasesClicks",
    "purchasesPromoted",
    "sales",
    "salesClicks",
    "salesPromoted",
    "topOfSearchImpressionShare",
    "unitsSold",
    "unitsSoldClicks",
    "video5SecondViewRate",
    "video5SecondViews",
    "videoCompleteViews",
    "videoFirstQuartileViews",
    "videoMidpointViews",
    "videoThirdQuartileViews",
    "videoUnmutes",
    "viewabilityRate",
    "viewableImpressions",
    "viewClickThroughRate",
]

BRANDS_AD_GROUP_METRICS = [
    "addToCart",
    "addToCartClicks",
    "addToCartRate",
    "adGroupId",
    "adGroupName",
    "adStatus",
    "brandedSearches",
    "brandedSearchesClicks",
    "campaignBudgetAmount",
    "campaignBudgetCurrencyCode",
    "campaignBudgetType",
    "campaignId",
    "campaignName",
    "campaignStatus",
    "clicks",
    "cost",
    "costType",
    "date",
    "detailPageViews",
    "detailPageViewsClicks",
    "eCPAddToCart",
    "impressions",
    "newToBrandDetailPageViewRate",
    "newToBrandDetailPageViews",
    "newToBrandDetailPageViewsClicks",
    "newToBrandECPDetailPageView",
    "newToBrandPurchases",
    "newToBrandPurchasesClicks",
    "newToBrandPurchasesPercentage",
    "newToBrandPurchasesRate",
    "newToBrandSales",
    "newToBrandSalesClicks",
    "newToBrandSalesPercentage",
    "newToBrandUnitsSold",
    "newToBrandUnitsSoldClicks",
    "newToBrandUnitsSoldPercentage",
    "purchases",
    "purchasesClicks",
    "purchasesPromoted",
    "sales",
    "salesClicks",
    "salesPromoted",
    "unitsSold",
    "unitsSoldClicks",
    "video5SecondViewRate",
    "video5SecondViews",
    "videoCompleteViews",
    "videoFirstQuartileViews",
    "videoMidpointViews",
    "videoThirdQuartileViews",
    "videoUnmutes",
    "viewabilityRate",
]

BRANDS_PLACEMENT_METRICS = [
    "addToCart",
    "addToCartClicks",
    "addToCartRate",
    "brandedSearches",
    "brandedSearchesClicks",
    "campaignBudgetAmount",
    "campaignBudgetCurrencyCode",
    "campaignBudgetType",
    "campaignId",
    "campaignName",
    "campaignStatus",
    "clicks",
    "cost",
    "costType",
    "date",
    "detailPageViews",
    "detailPageViewsClicks",
    "eCPAddToCart",
    "impressions",
    "newToBrandDetailPageViewRate",
    "newToBrandDetailPageViews",
    "newToBrandDetailPageViewsClicks",
    "newToBrandECPDetailPageView",
    "newToBrandPurchases",
    "newToBrandPurchasesClicks",
    "newToBrandPurchasesPercentage",
    "newToBrandPurchasesRate",
    "newToBrandSales",
    "newToBrandSalesClicks",
    "newToBrandSalesPercentage",
    "newToBrandUnitsSold",
    "newToBrandUnitsSoldClicks",
    "newToBrandUnitsSoldPercentage",
    "purchases",
    "purchasesClicks",
    "purchasesPromoted",
    "sales",
    "salesClicks",
    "salesPromoted",
    "unitsSold",
    "unitsSoldClicks",
    "video5SecondViewRate",
    "video5SecondViews",
    "videoCompleteViews",
    "videoFirstQuartileViews",
    "videoMidpointViews",
    "videoThirdQuartileViews",
    "videoUnmutes",
    "viewabilityRate",
    "viewableImpressions",
    "viewClickThroughRate",
]

BRANDS_TARGETING_METRICS = [
    "addToCart",
    "addToCartClicks",
    "addToCartRate",
    "adGroupId",
    "adGroupName",
    "adKeywordStatus",
    "brandedSearches",
    "brandedSearchesClicks",
    "campaignBudgetAmount",
    "campaignBudgetCurrencyCode",
    "campaignBudgetType",
    "campaignId",
    "campaignName",
    "campaignStatus",
    "clicks",
    "cost",
    "costType",
    "date",
    "detailPageViews",
    "detailPageViewsClicks",
    "eCPAddToCart",
    "impressions",
    "keywordBid",
    "keywordId",
    "keywordText",
    "keywordType",
    "matchType",
    "newToBrandDetailPageViewRate",
    "newToBrandDetailPageViews",
    "newToBrandDetailPageViewsClicks",
    "newToBrandECPDetailPageView",
    "newToBrandPurchases",
    "newToBrandPurchasesClicks",
    "newToBrandPurchasesPercentage",
    "newToBrandPurchasesRate",
    "newToBrandSales",
    "newToBrandSalesClicks",
    "newToBrandSalesPercentage",
    "newToBrandUnitsSold",
    "newToBrandUnitsSoldClicks",
    "newToBrandUnitsSoldPercentage",
    "purchases",
    "purchasesClicks",
    "purchasesPromoted",
    "sales",
    "salesClicks",
    "salesPromoted",
    "targetingExpression",
    "targetingId",
    "targetingText",
    "targetingType",
    "topOfSearchImpressionShare",
]

BRANDS_SEARCH_TERM_METRICS = [
    "adGroupId",
    "adGroupName",
    "campaignBudgetAmount",
    "campaignBudgetCurrencyCode",
    "campaignBudgetType",
    "campaignId",
    "campaignName",
    "campaignStatus",
    "clicks",
    "cost",
    "costType",
    "date",
    "impressions",
    "keywordBid",
    "keywordId",
    "keywordText",
    "matchType",
    "purchases",
    "purchasesClicks",
    "sales",
    "salesClicks",
    "searchTerm",
    "unitsSold",
    "video5SecondViewRate",
    "video5SecondViews",
    "videoCompleteViews",
    "videoFirstQuartileViews",
    "videoMidpointViews",
    "videoThirdQuartileViews",
    "videoUnmutes",
    "viewabilityRate",
    "viewableImpressions",
    "viewClickThroughRate",
]

BRANDS_AD_METRICS = [
    "addToCart",
    "addToCartClicks",
    "addToCartRate",
    "adGroupId",
    "adGroupName",
    "adId",
    "brandedSearches",
    "brandedSearchesClicks",
    "campaignBudgetAmount",
    "campaignBudgetCurrencyCode",
    "campaignBudgetType",
    "campaignId",
    "campaignName",
    "campaignStatus",
    "clicks",
    "cost",
    "costType",
    "date",
    "detailPageViews",
    "detailPageViewsClicks",
    "eCPAddToCart",
    "impressions",
    "newToBrandDetailPageViewRate",
    "newToBrandDetailPageViews",
    "newToBrandDetailPageViewsClicks",
    "newToBrandECPDetailPageView",
    "newToBrandPurchases",
    "newToBrandPurchasesClicks",
    "newToBrandPurchasesPercentage",
    "newToBrandPurchasesRate",
    "newToBrandSales",
    "newToBrandSalesClicks",
    "newToBrandSalesPercentage",
    "newToBrandUnitsSold",
    "newToBrandUnitsSoldClicks",
    "newToBrandUnitsSoldPercentage",
    "purchases",
    "purchasesClicks",
    "purchasesPromoted",
    "sales",
    "salesClicks",
    "salesPromoted",
    "unitsSold",
    "unitsSoldClicks",
    "video5SecondViewRate",
    "video5SecondViews",
    "videoCompleteViews",
    "videoFirstQuartileViews",
    "videoMidpointViews",
    "videoThirdQuartileViews",
    "videoUnmutes",
    "viewabilityRate",
    "viewableImpressions",
]

BRANDS_PURCHASED_PRODUCT_METRICS = [
    "adGroupId",
    "adGroupName",
    "attributionType",
    "campaignBudgetCurrencyCode",
    "campaignId",
    "campaignName",
    "date",
    "newToBrandPurchases14d",
    "newToBrandPurchasesPercentage14d",
    "newToBrandSales14d",
    "newToBrandSalesPercentage14d",
    "newToBrandUnitsSold14d",
    "newToBrandUnitsSoldPercentage14d",
    "orders14d",
    "productCategory",
    "productName",
    "purchasedAsin",
    "sales14d",
    "unitsSold14d",
]

BRANDS_GROSS_AND_INVALID_TRAFFIC_METRICS = [
    "campaignName",
    "campaignStatus",
    "clicks",
    "date",
    "grossClickThroughs",
    "grossImpressions",
    "impressions",
    "invalidClickThroughRate",
    "invalidClickThroughs",
    "invalidImpressionRate",
    "invalidImpressions",
]

# ------------------------------------------------------------------
# DISPLAY
# ------------------------------------------------------------------

DISPLAY_CAMPAIGN_METRICS = [
    "addToCart",
    "addToCartClicks",
    "addToCartRate",
    "addToCartViews",
    "brandedSearches",
    "brandedSearchesClicks",
    "brandedSearchesViews",
    "brandedSearchRate",
    "campaignBudgetAmount",
    "campaignBudgetCurrencyCode",
    "campaignId",
    "campaignName",
    "campaignStatus",
    "clicks",
    "cost",
    "costType",
    "cumulativeReach",
    "date",
    "detailPageViews",
    "detailPageViewsClicks",
    "eCPAddToCart",
    "eCPBrandSearch",
    "impressions",
    "impressionsFrequencyAverage",
    "impressionsViews",
    "newToBrandDetailPageViewClicks",
    "newToBrandDetailPageViewRate",
    "newToBrandDetailPageViews",
    "newToBrandDetailPageViewViews",
    "newToBrandECPDetailPageView",
    "newToBrandPurchases",
    "newToBrandPurchasesClicks",
    "newToBrandSales",
    "newToBrandSalesClicks",
    "newToBrandUnitsSold",
    "newToBrandUnitsSoldClicks",
    "purchases",
    "purchasesClicks",
    "purchasesPromotedClicks",
    "sales",
    "salesClicks",
    "salesPromotedClicks",
    "unitsSold",
    "unitsSoldClicks",
    "videoCompleteViews",
    "videoFirstQuartileViews",
    "videoMidpointViews",
    "videoThirdQuartileViews",
    "videoUnmutes",
    "viewabilityRate",
    "viewClickThroughRate",
]

DISPLAY_AD_GROUP_METRICS = [
    "addToCart",
    "addToCartClicks",
    "addToCartRate",
    "addToCartViews",
    "adGroupId",
    "adGroupName",
    "bidOptimization",
    "brandedSearches",
    "brandedSearchesClicks",
    "brandedSearchesViews",
    "brandedSearchRate",
    "campaignBudgetCurrencyCode",
    "campaignId",
    "campaignName",
    "clicks",
    "cost",
    "date",
    "detailPageViews",
    "detailPageViewsClicks",
    "eCPAddToCart",
    "eCPBrandSearch",
    "impressions",
    "impressionsViews",
    "newToBrandPurchases",
    "newToBrandPurchasesClicks",
    "newToBrandSales",
    "newToBrandSalesClicks",
    "newToBrandUnitsSold",
    "newToBrandUnitsSoldClicks",
    "purchases",
    "purchasesClicks",
    "purchasesPromotedClicks",
    "sales",
    "salesClicks",
    "salesPromotedClicks",
    "unitsSold",
    "unitsSoldClicks",
    "videoCompleteViews",
    "videoFirstQuartileViews",
    "videoMidpointViews",
    "videoThirdQuartileViews",
    "videoUnmutes",
    "viewabilityRate",
    "viewClickThroughRate",
]

DISPLAY_TARGETING_METRICS = [
    "addToCart",
    "addToCartClicks",
    "addToCartRate",
    "addToCartViews",
    "adGroupId",
    "adGroupName",
    "adKeywordStatus",
    "brandedSearches",
    "brandedSearchesClicks",
    "brandedSearchesViews",
    "brandedSearchRate",
    "campaignBudgetCurrencyCode",
    "campaignId",
    "campaignName",
    "clicks",
    "cost",
    "date",
    "detailPageViews",
    "detailPageViewsClicks",
    "eCPAddToCart",
    "eCPBrandSearch",
    "impressions",
    "impressionsViews",
    "newToBrandDetailPageViewClicks",
    "newToBrandDetailPageViewRate",
    "newToBrandDetailPageViews",
    "newToBrandDetailPageViewViews",
    "newToBrandECPDetailPageView",
    "newToBrandPurchases",
    "newToBrandPurchasesClicks",
    "newToBrandSales",
    "newToBrandSalesClicks",
    "newToBrandUnitsSold",
    "newToBrandUnitsSoldClicks",
    "purchases",
    "purchasesClicks",
    "purchasesPromotedClicks",
    "sales",
    "salesClicks",
    "salesPromotedClicks",
    "targetingExpression",
    "targetingId",
    "targetingText",
    "unitsSold",
    "unitsSoldClicks",
    "videoCompleteViews",
    "videoFirstQuartileViews",
    "videoMidpointViews",
    "videoThirdQuartileViews",
    "videoUnmutes",
    "viewabilityRate",
    "viewClickThroughRate",
]

DISPLAY_ADVERTISED_PRODUCT_METRICS = [
    "addToCart",
    "addToCartClicks",
    "addToCartRate",
    "addToCartViews",
    "adGroupId",
    "adGroupName",
    "adId",
    "bidOptimization",
    "brandedSearches",
    "brandedSearchesClicks",
    "brandedSearchesViews",
    "brandedSearchRate",
    "campaignBudgetCurrencyCode",
    "campaignId",
    "campaignName",
    "clicks",
    "cost",
    "cumulativeReach",
    "date",
    "detailPageViews",
    "detailPageViewsClicks",
    "eCPAddToCart",
    "eCPBrandSearch",
    "impressions",
    "impressionsFrequencyAverage",
    "impressionsViews",
    "newToBrandDetailPageViewClicks",
    "newToBrandDetailPageViewRate",
    "newToBrandDetailPageViews",
    "newToBrandDetailPageViewViews",
    "newToBrandECPDetailPageView",
    "newToBrandPurchases",
    "newToBrandPurchasesClicks",
    "newToBrandSales",
    "newToBrandSalesClicks",
    "newToBrandUnitsSold",
    "newToBrandUnitsSoldClicks",
    "promotedAsin",
    "promotedSku",
    "purchases",
    "purchasesClicks",
    "purchasesPromotedClicks",
    "sales",
    "salesClicks",
    "salesPromotedClicks",
    "unitsSold",
    "unitsSoldClicks",
    "videoCompleteViews",
    "videoFirstQuartileViews",
    "videoMidpointViews",
    "videoThirdQuartileViews",
    "videoUnmutes",
    "viewabilityRate",
    "viewClickThroughRate",
]

DISPLAY_PURCHASED_PRODUCT_METRICS = [
    "adGroupId",
    "adGroupName",
    "asinBrandHalo",
    "campaignBudgetCurrencyCode",
    "campaignId",
    "campaignName",
    "conversionsBrandHalo",
    "conversionsBrandHaloClicks",
    "date",
    "promotedAsin",
    "promotedSku",
    "salesBrandHalo",
    "salesBrandHaloClicks",
    "unitsSoldBrandHalo",
    "unitsSoldBrandHaloClicks",
]

DISPLAY_GROSS_AND_INVALID_TRAFFIC_METRICS = [
    "campaignName",
    "campaignStatus",
    "clicks",
    "date",
    "grossClickThroughs",
    "grossImpressions",
    "impressions",
    "invalidClickThroughRate",
    "invalidClickThroughs",
    "invalidImpressionRate",
    "invalidImpressions",
]

# ------------------------------------------------------------------
# TELEVISION
# ------------------------------------------------------------------

TELEVISION_CAMPAIGN_METRICS = [
    "addToCart",
    "addToCartClicks",
    "addToCartViews",
    "brandedSearches",
    "brandedSearchesClicks",
    "brandedSearchesViews",
    "campaignBudgetAmount",
    "campaignBudgetCurrencyCode",
    "campaignBudgetType",
    "campaignId",
    "campaignName",
    "campaignStatus",
    "clicks",
    "clickThroughRate",
    "cost",
    "costPerThousandImpressions",
    "date",
    "detailPageViews",
    "detailPageViewsClicks",
    "detailPageViewsViews",
    "impressions",
    "newToBrandDetailPageViewClicks",
    "newToBrandDetailPageViews",
    "newToBrandDetailPageViewViews",
    "newToBrandPurchases",
    "newToBrandPurchasesClicks",
    "newToBrandPurchasesViews",
    "newToBrandSales",
    "newToBrandSalesClicks",
    "newToBrandSalesViews",
    "portfolioId",
    "purchases",
    "purchasesClicks",
    "purchasesViews",
    "roas",
    "sales",
    "salesClicks",
    "salesViews",
    "unitsSold",
    "unitsSoldClicks",
    "unitsSoldViews",
    "videoCompleteViews",
    "videoFirstQuartileViews",
    "videoMidpointViews",
    "videoThirdQuartileViews",
]

TELEVISION_TARGETING_METRICS = [
    "addToCart",
    "addToCartClicks",
    "addToCartViews",
    "brandedSearches",
    "brandedSearchesClicks",
    "brandedSearchesViews",
    "clicks",
    "clickThroughRate",
    "cost",
    "costPerThousandImpressions",
    "date",
    "detailPageViews",
    "detailPageViewsClicks",
    "detailPageViewsViews",
    "impressions",
    "keyword",
    "keywordBid",
    "keywordId",
    "keywordType",
    "matchType",
    "newToBrandDetailPageViewClicks",
    "newToBrandDetailPageViews",
    "newToBrandDetailPageViewViews",
    "newToBrandPurchases",
    "newToBrandPurchasesClicks",
    "newToBrandPurchasesViews",
    "newToBrandSales",
    "newToBrandSalesClicks",
    "newToBrandSalesViews",
    "portfolioId",
    "purchases",
    "purchasesClicks",
    "purchasesViews",
    "roas",
    "sales",
    "salesClicks",
    "salesViews",
    "targetingText",
    "unitsSold",
    "unitsSoldClicks",
    "unitsSoldViews",
    "videoCompleteViews",
    "videoFirstQuartileViews",
    "videoMidpointViews",
    "videoThirdQuartileViews",
]
